@@ -29,7 +29,8 @@
 #include "gst.h"
 
 /* Main dialog general callbacks */
-void      on_table_clicked (GtkTreeSelection*, gpointer);
+void      on_lock_changed  (GstDialog*);
+void      on_table_selection_changed (GtkTreeSelection*, gpointer);
 gboolean  on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer gdata);
 gboolean  on_table_popup_menu   (GtkTreeView*, GtkWidget*);
 void      on_popup_add_activate (GtkAction*, gpointer);
